This package is designed for easy life of IMS Health company.
To see the list of available functions click on index below! Be happy, don't worry :)
Boris Demeshev
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.