str_sent2words: Convert vector of sentences to a data.frame of separate words

Description Usage Arguments Details Value Examples

Description

Convert vector of sentences to a data.frame of separate words

Usage

1
str_sent2words(x, cleanup = TRUE, sep = " ")

Arguments

x

the vector of sentences

cleanup

logical indicates whether to remove punctuation and some other cleanup

sep

separator of words, space by default

Details

Convert vector of sentences to a data.frame of separate words The output is a data.frame with 3 variables: word, word_n (number of word), sent_n (number of sentence)

Value

data.frame with 3 variables: word, word_n (number of word), sent_n (number of sentence) #

Examples

1
str_sent2words(c("привет","Маша, это я, Дубровский"))

bdemeshev/rims documentation built on May 12, 2019, 3:41 a.m.