str_utf2cp0: Change encoding of cyrillic text from "utf8" to "cp1251"

Description Usage Arguments Details Value Examples

Description

Change encoding of cyrillic text from "utf8" to "cp1251"

Usage

1
str_utf2cp0(x, backward = FALSE)

Arguments

x

the vector of cyrillic characters

backward

(default FALSE) TRUE: utf8 to cp1251, FALSE: cp1251 to utf8

Details

This function changes encoding of a vector from "utf8" to "cp1251" This function applies changes only to character and factor variables

Value

reencoded vector

Examples

1
str_utf2cp0("привет")

bdemeshev/rims documentation built on May 12, 2019, 3:41 a.m.