str_word: Get specific word from a vector of character sentences

Description Usage Arguments Details Value Examples

Description

Get specific word from a vector of character sentences

Usage

1
str_word(x, num = 1, remove.duplicate = TRUE)

Arguments

x

the vector of cyrillic characters

num

the number (numbers) of word, negative numbers mean "from the end of sentence"

remove.duplicate

logical, indicates whether the same word should be reported once or twice

Details

This function uses the transliteration tradition where "й" goes to "y"

Value

data frame of words with numbers #

Examples

1
str_word(c("привет","Маша, это я, Дубровский"))

bdemeshev/rims documentation built on May 12, 2019, 3:41 a.m.