Description Usage Arguments Details Value Examples
Change encoding of cyrillic text from "utf8" to "cp1251"
1 | str_utf2cp0(x, backward = FALSE)
|
x |
the vector of cyrillic characters |
backward |
(default FALSE) TRUE: utf8 to cp1251, FALSE: cp1251 to utf8 |
This function changes encoding of a vector from "utf8" to "cp1251" This function applies changes only to character and factor variables
reencoded vector
1 | str_utf2cp0("привет")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.